===============
Project History
===============

multigtfs was first developed for the `Tulsa Web Devs`_' project to get
Tulsa's buses into `Google Maps`_.  `tulsa-transit-google`_ is the
Tulsa-specific portion, and multigtfs contains the parts useful for any
GTFS effort.  `Tulsa's bus schedule appeared on
Google Maps in July 2013`_, after a two-year effort.  The Tulsa Web Devs
founded `Code for Tulsa`_ to collaborate on future civic tech projects.

Several features, including GeoDjango_ support and much faster feed imports,
were generously sponsored by MRCagney_.

.. _`Tulsa Web Devs`: http://tulsawebdevs.org
.. _`Google Maps`: https://www.google.com/intl/en/landing/transit/
.. _`tulsa-transit-google`: https://github.com/tulsawebdevs/tulsa-transit-google
.. _`Tulsa's bus schedule appeared on Google Maps in July 2013`:
    http://tulsawebdevs.org/tulsa-transit-schedules-integrated-into-google-maps/
.. _`Code for Tulsa`: http://codefortulsa.org
.. _GeoDjango: https://docs.djangoproject.com/en/dev/ref/contrib/gis/
.. _MRCagney: http://mrcagney.co.nz
